var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

// index.ts
import fetch from "node-fetch";
import { stringify } from "querystring";
var ACCESS_TOKEN_URL = "https://accounts.spotify.com/api/token";
var CURRENTLY_PLAYING_URL = `https://api.spotify.com/v1/me/player/currently-playing`;
var LAST_PLAYED_URL = `https://api.spotify.com/v1/me/player/recently-played`;
var filterResponse = (track) => {
  var _a;
  return {
    title: track == null ? void 0 : track.name,
    artist: (_a = track == null ? void 0 : track.artists) == null ? void 0 : _a.map((artist) => artist == null ? void 0 : artist.name).join(", "),
    link: track == null ? void 0 : track.external_urls.spotify
  };
};
var encodeToBase64 = (str) => Buffer.from(str).toString("base64");
var SpotifyClient = class {
  constructor({ clientId, clientSecret, refreshToken }) {
    this.accessToken = null;
    this._genAccesToken = async () => {
      const basicToken = encodeToBase64(`${this.clientId}:${this.clientSecret}`);
      const response = await fetch(ACCESS_TOKEN_URL, {
        method: "POST",
        headers: {
          Authorization: `Basic ${basicToken}`,
          "Content-Type": "application/x-www-form-urlencoded"
        },
        body: stringify({
          grant_type: "refresh_token",
          refresh_token: this.refreshToken
        })
      });
      const responseData = await response.json();
      return responseData == null ? void 0 : responseData.access_token;
    };
    this.getCurrentlyPlaying = async ({
      fallbackToLastPlayed = false
    } = {}) => {
      try {
        if (this.accessToken === null)
          this.accessToken = await this._genAccesToken();
        const headers = { Authorization: `Bearer ${this.accessToken}` };
        const response = await fetch(CURRENTLY_PLAYING_URL, { headers });
        if (response.status === 401) {
          this.accessToken = await this._genAccesToken();
          return this.getCurrentlyPlaying({ fallbackToLastPlayed });
        }
        let isPlaying = true;
        if (response.status === 204) {
          isPlaying = false;
          return fallbackToLastPlayed ? __spreadValues({ isPlaying }, (await this.getLastPlayed())[0]) : null;
        }
        const responseData = await response.json();
        const currentTrack = filterResponse(responseData == null ? void 0 : responseData.item);
        return __spreadValues({ isPlaying }, currentTrack);
      } catch (error) {
        throw new Error(error);
      }
    };
    this.getLastPlayed = async (limit = 1) => {
      try {
        if (this.accessToken === null)
          this.accessToken = await this._genAccesToken();
        if (limit > 50 || limit < 1)
          throw new Error("Limit must be between 1 and 50");
        const headers = { Authorization: `Bearer ${this.accessToken}` };
        const response = await fetch(`${LAST_PLAYED_URL}?limit=${limit}`, { headers });
        if (response.status === 401) {
          this.accessToken = await this._genAccesToken();
          return this.getLastPlayed(limit);
        }
        const responseData = await response.json();
        const lastPlayedTrack = responseData.items.map((item) => {
          return filterResponse(item.track);
        });
        return lastPlayedTrack;
      } catch (error) {
        throw new Error(error);
      }
    };
    this.clientId = clientId;
    this.clientSecret = clientSecret;
    this.refreshToken = refreshToken;
  }
};
export {
  SpotifyClient
};
